#
# spec file for package atuin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           atuin
Version:        16.0.0
Release:        bp156.1.4
Summary:        Magical shell history
License:        MIT
Group:          System/Console
URL:            https://github.com/ellie/atuin
Source0:        https://github.com/ellie/atuin/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        cargo_config
Source3:        0000-disable_update_check.patch
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  cargo-packaging
BuildRequires:  rust+cargo >= 1.59
BuildRequires:  zstd

%description
Atuin replaces your existing shell history with a SQLite database, and records additional context for your commands.
Additionally, it provides optional and fully encrypted synchronisation of your history between machines, via an Atuin server.

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -a1 -p1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build} --all-features

for shell in "zsh" "bash" "fish"
do
  ./target/release/%{name} gen-completions --shell "$shell" > target/%{name}."$shell"
done

%install
install -D -m 0755 "%{_builddir}/%{name}-%{version}/target/release/atuin" "%{buildroot}%{_bindir}/atuin"
install -D -m 0644 "target/%{name}.bash" "%{buildroot}/%{_datadir}/bash-completion/completions/%{name}"
install -D -m 0644 "target/%{name}.fish" "%{buildroot}/%{_datadir}/fish/vendor_completions.d/%{name}.fish"
install -D -m 0644 "target/%{name}.zsh" "%{buildroot}/%{_datadir}/zsh/site-functions/_%{name}"

%files
%license LICENSE
%doc README.md CHANGELOG.md atuin/src/shell
%{_bindir}/atuin

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Wed Sep 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix and update generated vendored tarball.
* Sat Sep  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.16.0:
  * Add graceful shutdown on SIGTERM
  * Update Arch Linux links in README
  * fix: Adjust broken link to supported shells
  * feat: do not allow empty passwords durring account creation
  * Fix movement keys in inverted mode
  * Make Ctrl-d behaviour match other tools
  * refactor server to allow pluggable db and tracing
  * Add support to override hostname and username via env vars
  * Fix --delete-it-all and --delete commands
  * Make requirement of PostgreSQL 14 explicit
  * Bug/fix gh action aarch64 tarball
  * Key values
  * Add namespaces to kv store
  * Builder interface for History objects
  * clean apt cache in Dockerfile
  * remove rmp-serde
  * fix: fixes unix specific impl of shutdown_signal
  * Add RecordIndex data structure
  * remove decryption from api-client
  * Revamp getting started guide
  * Redirect old docs
  * Move key binding docs so they can be more easily found
  * record encryption
  * Fix nu section in key-bindings.md - set-env -> let-env
  * Update Nushell support to use support* remove decryption from api-client
  * Revamp getting started guide
  * Redirect old docs
  * Move key binding docs so they can be more easily found
  * record encryption
  * Fix nu section in key-bindings.md - set-env -> let-env
  * Update Nushell support to use supported $env update syntax
  * fix key encodings again
  * Update config.toml path default comments
  * fix for zsh no-unset environments
  * atuin crypto blog post
  * Add OG image
  * write some key tests
  * Add new sync
  * Add total history count to the index API
  * Delete the count cache row when a user is deleted
  * Add workspace mode, enable if in git repo
  * Unvendor ratatui
  * skim: fix filtering aggregates
  * Serve docusaurus on /docs/
  * Try adjusting docs root
  * Remove vercel config
  * Tidy up docs
  * use Ctrl-n instead of Alt-n on macOS
  * some simple server tests
  * Disable server tests in the nix build
  * Drop default sync frequency to 10m
  * Move all references to the old repo
  * Add self hosted runner
  * Split integration and unit tests, use runner for unit
  * fix(server): Teapot is a cup of coffee
  * rebase: fix: nushell empty hooks
  * Add support for max_preview_height setting
  * fix(docs): List all presently documented commands
  * encode paseto payloads as json
  * fix(docs): Correct command overview paths
  * Prepare release v16.0.0
  * fix key encodings again
  * Update config.toml path default comments
  * fix for zsh no-unset environments
  * atuin crypto blog post
  * Add OG image
  * write some key tests
  * Add new sync
  * Add total history count to the index API
  * Delete the count cache row when a user is deleted
  * Add workspace mode, enable if in git repo
  * Unvendor ratatui
  * skim: fix filtering aggregates
  * Serve docusaurus on /docs/
  * Try adjusting docs root
  * Remove vercel config
  * Tidy up docs
  * use Ctrl-n instead of Alt-n on macOS
  * some simple server tests
  * Disable server tests in the nix build
  * Drop default sync frequency to 10m
  * Move all references to the old repo
  * Add self hosted runner
  * Split integration and unit tests, use runner for unit
  * fix(server): Teapot is a cup of coffee
  * rebase: fix: nushell empty hooks
  * Add support for max_preview_height setting
  * fix(docs): List all presently documented commands
  * encode paseto payloads as json
  * fix(docs): Correct command overview paths
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Mon May 29 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 15.0.0:
  * Fix release workflow
  * Add workflow dispatch for release
  * chore: uuhhhhhh crypto lol
  * Add keyboard shortcuts to the Config/Keybinding chapter.
  * Re-added package name to workspace.package
  * Add package param to cargo deb
  * Allow specifying tag to build for workflow_dispatch
  * Add symlink
  * Upload tar before building deb
  * Copy license for cargo-deb
  * Fix fig plugin link
  * fix broken pipe on history list
  * docs: Fix broken links in README.md
  * Add nu section to keybinds.md
  * cwd_filter: much like history_filter, only it applies to cwd
  * Add command flag for inline_height
  * docs: fix "From source" cd command
  * Correct typos in website
  * website: Fix participle "be ran" -> "be run"
  * Update README.md: Disable update check for offline mode
  * At least patch this on the server side so we don't loop forever
  * Fix key regression
  * Include bash preexec warning
  * feat: add delete account option (attempt 2)
  * validate usernames on registration
  * Restructure account commands to account subcommand
  * Allow server configured page size
  * Input bar at the top if we are in inline mode
  * Add option to completely disable help row
  * Fix typo in config.toml
* Sun May  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix installation step in specfile.
* Sat Apr 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 14.0.1 patch release:
  * Fix deleting history that doesn't exist yet
  * Updated client config docs
  * Handle empty lines when importing from Bash
  * update str substring usage to use range parameter
  * Fix --delete description
  * Use XDG data directory for fish import
  * Add some emacs movement keys
  * Atuin stats with day, month, week and year filter
  * Add --reverse to atuin search
  * Add additional detail to search documentation
  * Switch to uuidv7
  * Workspace reorder
  * Improve error message for issue #850.
  * Avoid accidentally deleting all history, but allow it if intended
  * Add footer
  * Make the homepage prettier
  * Release v14.0.1
* Sat Apr 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add _constraints
  * Make disk size to 12G to fix build failure "No space left on device"
* Fri Apr 14 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 14.0.0:
  * Add Hachyderm links
  * Update flake.lock to Rust 1.67
  * nix: add flake-compat
  * Fix race condition in directory tests
  * Rework Bash import
  * docs(README): fix activity graph link
  * Show preview of selected command
  * Up arrow filter_mode setting default to global filter mode
  * feat: add common default keybindings
  * Bump debian from bullseye-20230208-slim to bullseye-20230227-slim
  * Windows support
  * fix(client): always read session_path from settings
  * Add register notification webhook
  * Install CA certificates in docker image
  * Docker isn't interactive ofc
  * Minor documentation updates
  * Fix before/after combined with limit
  * Allow specifying fulltext as well as full-text
  * fix new stats unique count
  * add common prefixes and subcommands to stats
  * fix(installer): use case-insensitive comparisons
  * Fixes a bug on windows
  * Prefer PWD environment variable over cwd if available to better support symbolic links
  * fix: many links were broken 📝
  * skim-demo
  * Add history deletion
  * fix: paste into terminal after switching modes
  * Support old msgpack
  * Fix skim search
  * Allow changing search_mode during interactive search
  * chore: remove tui vendoring
  * Bump debian from bullseye-20230227-slim to bullseye-20230320-slim
  * Delete all instances of a command
  * Bump lukemathwalker/cargo-chef from latest-rust-1.67.1 to latest-rust-1.68.0
  * feat: respect exit_mode setting when exiting with arrow down keypress
  * feat: add an inline view mode
  * Add musl build
  * feat: add Nushell support
  * chore: use fork of skim
  * Bind keys in vi mode too
  * Account for user not yet having count cache
  * Fixes nushell recording empty commands
  * Update CONTRIBUTING.md
  * client filtering done in query
  * fix: record negative exit codes
  * Refactor/nu remove dep on sh
  * Update CI
  * Add more fields to atuin search --format
  * install.sh - add endeavouros to archlinux detection
  * Add --offset flag to atuin search
  * Update atuin search docs
  * Add atuin status
  * fix: allow nix package to fetch dependencies from git
  * feat: add github action to test the nix builds
  * Vendor ratatui temporarily
* Sat Mar 25 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 13.0.1:
  * Enable RUST_BACKTRACE for docker builds
  * Revert "Re-enable arm docker builds"
  * Fix editURL for docs
  * Fix link to self-hosting
  * [docs] fix some links between config and commands
  * Disable 2 tests that shouldn't run in release mode
  * fix registration
* Mon Feb 27 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Disable update check by default since updates are handled in OBS
* Sun Feb 26 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 13.0.0:
  * Improvements
  - Better error messages
  - Nix install files + instructions
  - Exit when pushing the down arrow from the most recent entry
  - Refactor to support generic server-side databases
  - Make it easier to disable the ctrl-r and/or up arrow bindings
  - Update to axum6
  * Fixes
  - Fish now handles multi-line commands properly
  - Listing history for the current session now works
  - Fix atuin init for Fish
  * New features
  - Pretty stats
  - Custom history list format
  - History filter
  - Mnemonic key
  * Crossterm as the new TUI backend
* Thu Nov 17 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix installation of shell completions.
- Add extra shell stuff in docs.
* Sat Nov 12 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 12.0.0:
  * Allow stateless commands to be run without config/database by @c-14 in #544
  * Clear RBUFFER when accepting output from atuin by @c-14 in #545
  * Add installer support for Termux by @laurentlbm in #540
  * Bump lukemathwalker/cargo-chef from latest-rust-1.63 to latest-rust-1.64.0 by @dependabot in #546
  * Add contributors command by @ellie in #550
  * Add style to config.toml and config.md by @xfzv in #552
  * Fix compatability with fish vi key bindings by @shreve in #541
  * add some error messages by @conradludgate in #510
  * update zh-CN docs by @helbing in #539
  * Bump debian from bullseye-20220822-slim to bullseye-20221004-slim by @dependabot in #551
  * Add automatic update checking by @ellie in #555
  * Bump sqlx from 0.5.13 to 0.6.2 by @dependabot in #536
  * Bump indicatif from 0.16.2 to 0.17.1 by @dependabot in #537
  * Bump rpassword from 6.0.1 to 7.0.0 by @dependabot in #530
  * Bump tui from 0.18.0 to 0.19.0 by @dependabot in #531
  * Bump rmp-serde from 1.1.0 to 1.1.1 by @dependabot in #557
  * Bump unicode-width from 0.1.9 to 0.1.10 by @dependabot in #535
  * rollup of 5 dependency commits by @conradludgate in #562
  * Add message begging for help lol turtle by @ellie in #569
  * upgrade clap by @conradludgate in #568
  * Configure reqwest to use native platform certs by @wpbrz in #574
  * Bump async-trait from 0.1.57 to 0.1.58 by @dependabot in #575
  * Never use HISTFILE for fish shell import by @patricksjackson in #573
  * Respect fish shell's builtin private mode by @patricksjackson in #577
  * Bump clap from 4.0.15 to 4.0.18 by @dependabot in #578
  * docs: add more details about date parsing in the stats command by @bvergnaud in #579
  * Make fuzzy search the default by @ellie in #591
  * Update server.md by @pevogam in #589
  * Exit with return code 1 when no results are found in atuin search command by @TymanWasTaken in #489
  * Update README.md with antigen instruction. by @DanielAtCosmicDNA in #549
  * Build ARM64 releases & update runners by @Absolucy in #593
  * Add local event log storage by @ellie in #390
  * fix #596: Avoid drawing a command section beyond the width of the list by @s0 in #597
  * Add setting for keeping typed query when exiting by @s0 in #451
  * Fix copy/paste artifact by @EricCrosson in #598
  * Release v12 by @ellie in #599
* Tue Oct 11 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Add shell completion packages
* Thu Oct  6 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Set rust+cargo version at least 1.59.
* Thu Sep 29 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec of atuin version 11.0.0
